# Python Package for Utility
@created by [huni1023](https://github.com/huni1023)

## Motivation
I've been managed various data like questionnaire, item responses, and system logs.
Thery are sometimes well-organized but in many times, it is unstructured and unshaped.
Through out my experience, I've been established my data-handling-routines.
The package `huni_utils` is my first python package, and it's a collection of python uility that I used frequently.
I hope this code might helpful for others too, and always welcome for advice or suggestion.

## Installation
The `huni_utils` is released in [PyPI](https://pypi.org/project/huni-utils/)
```bash
pip install huni-utils
```

## Function
### 1. load and save files
- read_pkl
- save_pkl
- read_yaml
- pandize_folder
### 2. handle os
- validate structure of project directory
- clear directory
- split_task
- search_file
### 3. measurement
- classical test theory
    - calculate item difficulty and discrimination
    - visualize item parameter (in developing)
- irt (in developing)

## Suggestion
- any functions are needed, leave issues behind or [e-mail me](mailto:jhun1023@naver.com)
